from u3driver.commands.command_returning_alt_elements import CommandReturningAltElements
# from u3driver.by import By
# import json
class GetHierarchy(CommandReturningAltElements):
    def __init__(self, socket,request_separator,request_end,appium_driver):
        super(GetHierarchy, self).__init__(socket,request_separator,request_end,appium_driver)
    
    def execute(self):
        data = self.send_data(self.create_command('getHierarchy'))
        return data



import json

from u3driver.commands.command_returning_alt_elements import CommandReturningAltElements


class GetScreen(CommandReturningAltElements):
    def __init__(self, socket,request_separator,request_end,appium_driver):
        super(GetScreen, self).__init__(socket,request_separator,request_end,appium_driver)
    
    def execute(self):
        json_data = self.send_data(self.create_command('getScreen'))
        data = json.loads(json_data)
        return data['width'], data['height']


from u3driver.commands.base_command import BaseCommand

class RecordProfile(BaseCommand):
    '''
    record = 0 停止打点
    record = 1 开始打点
    '''
    def __init__(self, socket,request_separator,request_end,record):
        super(RecordProfile, self).__init__(socket,request_separator,request_end)
        self.record = record

    def execute(self):
        data = self.send_data(self.create_command('RecordProfile',self.record))
        print(data)
        


from u3driver.commands.command_returning_alt_elements import CommandReturningAltElements
class FindObjectInRangeWhereNameContains(CommandReturningAltElements):
    def __init__(self, socket,request_separator,request_end,appium_driver,value,range_path,camera_name,enabled):
        super(FindObjectInRangeWhereNameContains, self).__init__(socket,request_separator,request_end,appium_driver)
        self.value=value
        self.range_path = range_path
        self.camera_name=camera_name
        self.enabled=enabled
    
    def execute(self):
        data = self.send_data(self.create_command('findObjectInRangeWhereNameContains', self.value ,self.range_path, self.camera_name,'true' ))
        return self.get_alt_elements(data)


from u3driver.commands.command_returning_alt_elements import CommandReturningAltElements
class TapAtCoordinates(CommandReturningAltElements):
    def __init__(self, socket,request_separator,request_end,appium_driver,x,y):
        super(TapAtCoordinates, self).__init__(socket,request_separator,request_end,appium_driver)
        self.x=x
        self.y=y
    
    def execute(self):
        data=self.send_data(self.create_command('tapScreen',self.x, self.y))
        if 'error:notFound' in data:
            return None
        return self.get_alt_element(data)


import json

from u3driver.commands.command_returning_alt_elements import CommandReturningAltElements


class FindAllObjectWhereTextContains(CommandReturningAltElements):
    def __init__(self, socket,request_separator,request_end,appium_driver,text):
        super(FindAllObjectWhereTextContains, self).__init__(socket,request_separator,request_end,appium_driver)
        self.text = text

    def execute(self):
        data = self.send_data(self.create_command('findAllObjectWhereTextContains',self.text))
        res = json.loads(data)
        return res



import json

from u3driver.commands.command_returning_alt_elements import CommandReturningAltElements


class FindAllObjectInRangeWhereTextContains(CommandReturningAltElements):
    def __init__(self, socket,request_separator,request_end,appium_driver,value,text):
        super(FindAllObjectInRangeWhereTextContains, self).__init__(socket,request_separator,request_end,appium_driver)
        self.value=value
        self.text = text

    
    def execute(self):
        data = self.send_data(self.create_command('findAllObjectInRangeWhereTextContains', self.value,self.text))
        return json.loads(data)['name']
    


import os

from u3driver.commands.base_command import BaseCommand

THIS_FOLDER = os.path.dirname(os.path.abspath(__file__))
my_file = os.path.join(THIS_FOLDER, 'PythonServerVersion.txt')

class GetServerVersion(BaseCommand):

    def __init__(self, socket,request_separator,request_end):
        super().__init__(socket,request_separator,request_end)
    
    def execute(self):
        serverVersion=self.send_data(self.create_command('getServerVersion'))
        serverVersion=self.handle_errors(serverVersion)
        
        # if not VERSION==serverVersion:
        #     message="Version mismatch. You are using different versions of server and driver. Server version: " + serverVersion + " and Driver version: " + VERSION
        #     warnings.warn(message)
        #     super().write_to_log_file(message)
        #     return "Version mismatch"
        # else:
        return serverVersion



from u3driver.commands.command_returning_alt_elements import CommandReturningAltElements


class GetValueOnComponent(CommandReturningAltElements):
    def __init__(self, socket,request_separator,request_end,appium_driver,path,componetName,valueName):
        super(GetValueOnComponent, self).__init__(socket,request_separator,request_end,appium_driver)
        self.path=path
        self.componetName = componetName
        self.valueName = valueName
    
    def execute(self):
        data = self.send_data(self.create_command('getValueOnComponent', self.path,self.componetName,self.valueName))
        return data



from u3driver.commands.command_returning_alt_elements import CommandReturningAltElements


class ObjectExist(CommandReturningAltElements):
    def __init__(self, socket,request_separator,request_end,appium_driver,by,value):
        super(ObjectExist, self).__init__(socket,request_separator,request_end,appium_driver)
        self.by=by
        self.value=value

    
    def execute(self, false=False):
        path = self.set_path(self.by,self.value)
        data = self.send_data(self.create_command('objectExist', path))
        if data == '1' or data == 1:
            return True
        else:
            return false


import json

from u3driver.commands.ObjectCommands.drag import Drag
from u3driver.commands.ObjectCommands.get_text import GetText
from u3driver.commands.ObjectCommands.set_text import SetText
from u3driver.commands.ObjectCommands.tap import Tap
from u3driver.commands.ObjectCommands.find import Find
from u3driver.commands.ObjectCommands.child_index import ChildIndex
from u3driver.commands.ObjectCommands.parent import Parent


class AltElement(object):
    def __init__(self, alt_unity_driver, appium_driver, json_data):
        self.alt_unity_driver = alt_unity_driver
        self.appium_driver=None
        if (appium_driver != None):
            self.appium_driver = appium_driver
        data = json.loads(json_data)
        self.name = str(data['name'])
        self.id = str(data['id'])
        self.x = ''#str(data['x'])
        self.y = ''#str(data['y'])
        self.z=''#str(data['z'])
        self.mobileY = ''#str(data['mobileY'])
        self.type = ''#str(data['type'])
        self.enabled = ''#str(data['enabled'])
        self.worldX = ''#str(data['worldX'])
        self.worldY = ''#str(data['worldY'])
        self.worldZ = ''#str(data['worldZ'])
        self.idCamera=''#str(data['idCamera'])

    def toJSON(self):
        dict = {
            'name': self.name,
            'id' : self.id
        }
        return json.dumps(dict)

    def get_screen_position(self):
        return self.x, self.y
    
    def get_world_position(self):
        return self.worldX, self.worldY, self.worldZ
    
    def get_text(self):
        alt_object = self.toJSON()
        return GetText(self.alt_unity_driver.socket,self.alt_unity_driver.request_separator,self.alt_unity_driver.request_end,alt_object).execute()
    
    def set_text(self, text):
        alt_object = self.toJSON()
        data = SetText(self.alt_unity_driver.socket,self.alt_unity_driver.request_separator,self.alt_unity_driver.request_end,text,alt_object).execute()
        return AltElement(self.alt_unity_driver, self.appium_driver, data)
        
    def mobile_tap(self, durationInSeconds=0.5):
        self.appium_driver.tap([[float(self.x), float(self.mobileY)]], durationInSeconds * 1000)
    
    def mobile_dragTo(self, end_x, end_y, durationIndSeconds=0.5):
        self.appium_driver.swipe(self.x, self.mobileY, end_x, end_y, durationIndSeconds* 1000)

    def mobile_dragToElement(self, other_element, durationIndSeconds=0.5):
        self.appium_driver.swipe(self.x, self.mobileY, other_element.x, other_element.mobileY, durationIndSeconds* 1000)
    
    def drag(self, x1, y1,x2 = None,y2 = None):
        data = Drag(self.alt_unity_driver.socket,self.alt_unity_driver.request_separator,self.alt_unity_driver.request_end,self.name,x1,y1,x2,y2).execute()
        return data

    def tap(self):
        alt_object=self.toJSON()
        data= Tap(self.alt_unity_driver.socket,self.alt_unity_driver.request_separator,self.alt_unity_driver.request_end,alt_object).execute()
        return AltElement(self.alt_unity_driver,self.appium_driver,data)
        
    def find(self, value):
        alt_object=self.toJSON()
        data = Find(self.alt_unity_driver.socket,self.alt_unity_driver.request_separator,self.alt_unity_driver.request_end,alt_object, value).execute()
        return AltElement(self.alt_unity_driver,self.appium_driver,data)
    
    def child_index(self, value):
        alt_object=self.toJSON()
        data = ChildIndex(self.alt_unity_driver.socket,self.alt_unity_driver.request_separator,self.alt_unity_driver.request_end,alt_object, value).execute()
        return AltElement(self.alt_unity_driver,self.appium_driver,data)

    def parent(self):
        alt_object=self.toJSON()
        data = Parent(self.alt_unity_driver.socket,self.alt_unity_driver.request_separator,self.alt_unity_driver.request_end,alt_object).execute()
        return AltElement(self.alt_unity_driver,self.appium_driver,data)



from u3driver.commands.FindObjects import *
from u3driver.commands.InputActions import *
from u3driver.commands.ObjectCommands import *
from u3driver.commands.close_connection import *
from u3driver.commands.debug_mode import *
from u3driver.commands.enable_logging import *
from u3driver.commands.get_server_version import *
from u3driver.commands.record_profile import *


import json

from u3driver.commands.command_returning_alt_elements import CommandReturningAltElements


class FindChild(CommandReturningAltElements):
    def __init__(self, socket,request_separator,request_end,appium_driver,value):
        super(FindChild, self).__init__(socket,request_separator,request_end,appium_driver)
        self.value=value
    
    def execute(self):
        data = self.send_data(self.create_command('findChild', self.value))
        res = json.loads(data)
        ret = []
        
        for item in res:
            ret.append(item['name'])
        
        return ret



import time

from u3driver.commands.base_command import BaseCommand


class CloseConnection(BaseCommand):
    def __init__(self, socket,request_separator,request_end):
        super(CloseConnection, self).__init__(socket,request_separator,request_end)
    
    def execute(self):
        data = self.send_data(self.create_command('closeConnection'))
        print('Sent close connection command...')
        time.sleep(1)
        self.socket.close()
        self.connect = False
        print('Socket closed.')  
        